==> nextcloud-30.0.12.tgz: nextcloud/apps/survey_client/l10n/lv.js <==
OC.L10N.register(
    "survey_client",
    {
    "An error occurred while sending your report." : "Atgadījās kļūda ziņojuma nosūtīšanas laikā.",
    "Database environment <em>(type, version, database size)</em>" : "Datubāzes vide <em>(veids, versija, datubāzes izmērs)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Šifrēšanas informācija <em>(Tā ir iespējota? Kāds ir noklusējuma modulis?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Koplietojumu skaits <em>(pēc tipa un piekļuvju uzstādījumiem)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP vide <em>(versija, atmiņas limits, max. izpildes laiks, max. datnes izmērs)</em>",
    "Usage survey" : "Izmantojamības aptauja",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Ir vēlme mums palīdzēt uzlabot Nextcloud, sniedzot anonimizētus datus par savu iestatni un lietojumu? To jebkurā brīdī var atkal atspējot pārvaldības iestatījumos.",
    "Send usage" : "Nosūtīt lietojumu",
    "Not now" : "Ne tagad",
    "Never" : "Nekad",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Tu vari palīdzēt uzlabot Nextcloud ar datu par pašreizējo iestatni un lietojumu nosūtīšanu.",
    "Send new report now" : "Nosūtīt jaunu atskaiti tūlīt",
    "Send usage survey monthly" : "Sūtīt izmantojamības aptauju ik mēnesi",
    "Data to send" : "Dati sūtīšanai",
    "Last report" : "Pēdējā atskaite"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-31.0.12p0.tgz: nextcloud/apps/survey_client/l10n/lv.js <==
OC.L10N.register(
    "survey_client",
    {
    "An error occurred while sending your report." : "Atgadījās kļūda ziņojuma nosūtīšanas laikā.",
    "Database environment <em>(type, version, database size)</em>" : "Datubāzes vide <em>(veids, versija, datubāzes izmērs)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Šifrēšanas informācija <em>(Tā ir iespējota? Kāds ir noklusējuma modulis?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Koplietojumu skaits <em>(katram veida un atļauju iestatījumam)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP vide <em>(versija, atmiņas limits, max. izpildes laiks, max. datnes izmērs)</em>",
    "Usage survey" : "Izmantojamības aptauja",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Ir vēlme mums palīdzēt uzlabot Nextcloud, sniedzot anonimizētus datus par savu iestatni un lietojumu? To jebkurā brīdī var atkal atspējot pārvaldības iestatījumos.",
    "Send usage" : "Nosūtīt lietojumu",
    "Not now" : "Ne tagad",
    "Never" : "Nekad",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Tu vari palīdzēt uzlabot Nextcloud ar datu par pašreizējo iestatni un lietojumu nosūtīšanu.",
    "Send new report now" : "Nosūtīt jaunu atskaiti tūlīt",
    "Send usage survey monthly" : "Sūtīt izmantojamības aptauju ik mēnesi",
    "Data to send" : "Dati sūtīšanai",
    "Last report" : "Pēdējā atskaite"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
